import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::AppStream::AppBlock
 */
export declare class AppBlock extends pulumi.CustomResource {
    /**
     * Get an existing AppBlock resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AppBlock;
    /**
     * Returns true if the given object is an instance of AppBlock.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AppBlock;
    /**
     * The ARN of the app block.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The time when the app block was created.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * The description of the app block.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The display name of the app block.
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * The name of the app block.
     *
     * *Pattern* : `^[a-zA-Z0-9][a-zA-Z0-9_.-]{0,100}$`
     */
    readonly name: pulumi.Output<string>;
    /**
     * The packaging type of the app block.
     */
    readonly packagingType: pulumi.Output<string | undefined>;
    /**
     * The post setup script details of the app block.
     */
    readonly postSetupScriptDetails: pulumi.Output<outputs.appstream.AppBlockScriptDetails | undefined>;
    /**
     * The setup script details of the app block.
     */
    readonly setupScriptDetails: pulumi.Output<outputs.appstream.AppBlockScriptDetails | undefined>;
    /**
     * The source S3 location of the app block.
     */
    readonly sourceS3Location: pulumi.Output<outputs.appstream.AppBlockS3Location>;
    /**
     * The tags of the app block.
     */
    readonly tags: pulumi.Output<(outputs.appstream.AppBlockTag0Properties | outputs.appstream.AppBlockTag1Properties)[] | undefined>;
    /**
     * Create a AppBlock resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AppBlockArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AppBlock resource.
 */
export interface AppBlockArgs {
    /**
     * The description of the app block.
     */
    description?: pulumi.Input<string>;
    /**
     * The display name of the app block.
     */
    displayName?: pulumi.Input<string>;
    /**
     * The name of the app block.
     *
     * *Pattern* : `^[a-zA-Z0-9][a-zA-Z0-9_.-]{0,100}$`
     */
    name?: pulumi.Input<string>;
    /**
     * The packaging type of the app block.
     */
    packagingType?: pulumi.Input<string>;
    /**
     * The post setup script details of the app block.
     */
    postSetupScriptDetails?: pulumi.Input<inputs.appstream.AppBlockScriptDetailsArgs>;
    /**
     * The setup script details of the app block.
     */
    setupScriptDetails?: pulumi.Input<inputs.appstream.AppBlockScriptDetailsArgs>;
    /**
     * The source S3 location of the app block.
     */
    sourceS3Location: pulumi.Input<inputs.appstream.AppBlockS3LocationArgs>;
    /**
     * The tags of the app block.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.appstream.AppBlockTag0PropertiesArgs | inputs.appstream.AppBlockTag1PropertiesArgs>[]>;
}
