import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::AutoScaling::WarmPool.
 */
export declare function getWarmPool(args: GetWarmPoolArgs, opts?: pulumi.InvokeOptions): Promise<GetWarmPoolResult>;
export interface GetWarmPoolArgs {
    /**
     * The name of the Auto Scaling group.
     */
    autoScalingGroupName: string;
}
export interface GetWarmPoolResult {
    /**
     * Indicates whether instances in the Auto Scaling group can be returned to the warm pool on scale in. The default is to terminate instances in the Auto Scaling group when the group scales in.
     */
    readonly instanceReusePolicy?: outputs.autoscaling.WarmPoolInstanceReusePolicy;
    /**
     * Specifies the maximum number of instances that are allowed to be in the warm pool or in any state except `Terminated` for the Auto Scaling group. This is an optional property. Specify it only if you do not want the warm pool size to be determined by the difference between the group's maximum capacity and its desired capacity.
     *
     * > If a value for `MaxGroupPreparedCapacity` is not specified, Amazon EC2 Auto Scaling launches and maintains the difference between the group's maximum capacity and its desired capacity. If you specify a value for `MaxGroupPreparedCapacity` , Amazon EC2 Auto Scaling uses the difference between the `MaxGroupPreparedCapacity` and the desired capacity instead.
     * >
     * > The size of the warm pool is dynamic. Only when `MaxGroupPreparedCapacity` and `MinSize` are set to the same value does the warm pool have an absolute size.
     *
     * If the desired capacity of the Auto Scaling group is higher than the `MaxGroupPreparedCapacity` , the capacity of the warm pool is 0, unless you specify a value for `MinSize` . To remove a value that you previously set, include the property but specify -1 for the value.
     */
    readonly maxGroupPreparedCapacity?: number;
    /**
     * Specifies the minimum number of instances to maintain in the warm pool. This helps you to ensure that there is always a certain number of warmed instances available to handle traffic spikes. Defaults to 0 if not specified.
     */
    readonly minSize?: number;
    /**
     * Sets the instance state to transition to after the lifecycle actions are complete. Default is `Stopped` .
     */
    readonly poolState?: string;
}
/**
 * Resource schema for AWS::AutoScaling::WarmPool.
 */
export declare function getWarmPoolOutput(args: GetWarmPoolOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWarmPoolResult>;
export interface GetWarmPoolOutputArgs {
    /**
     * The name of the Auto Scaling group.
     */
    autoScalingGroupName: pulumi.Input<string>;
}
