import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of AWS::B2BI::Partnership Resource Type
 */
export declare function getPartnership(args: GetPartnershipArgs, opts?: pulumi.InvokeOptions): Promise<GetPartnershipResult>;
export interface GetPartnershipArgs {
    /**
     * Returns the unique, system-generated identifier for a partnership.
     */
    partnershipId: string;
}
export interface GetPartnershipResult {
    /**
     * Returns one or more capabilities associated with this partnership.
     */
    readonly capabilities?: string[];
    /**
     * Contains the details for an Outbound EDI capability.
     */
    readonly capabilityOptions?: outputs.b2bi.PartnershipCapabilityOptions;
    /**
     * Returns a timestamp for creation date and time of the partnership.
     */
    readonly createdAt?: string;
    /**
     * Returns a timestamp that identifies the most recent date and time that the partnership was modified.
     */
    readonly modifiedAt?: string;
    /**
     * Returns the name of the partnership.
     */
    readonly name?: string;
    /**
     * Returns an Amazon Resource Name (ARN) for a specific AWS resource, such as a capability, partnership, profile, or transformer.
     */
    readonly partnershipArn?: string;
    /**
     * Returns the unique, system-generated identifier for a partnership.
     */
    readonly partnershipId?: string;
    /**
     * A key-value pair for a specific partnership. Tags are metadata that you can use to search for and group capabilities for various purposes.
     */
    readonly tags?: outputs.Tag[];
    /**
     * Returns the unique, system-generated identifier for a trading partner.
     */
    readonly tradingPartnerId?: string;
}
/**
 * Definition of AWS::B2BI::Partnership Resource Type
 */
export declare function getPartnershipOutput(args: GetPartnershipOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetPartnershipResult>;
export interface GetPartnershipOutputArgs {
    /**
     * Returns the unique, system-generated identifier for a partnership.
     */
    partnershipId: pulumi.Input<string>;
}
