import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Bedrock::Agent Resource Type
 */
export declare function getAgent(args: GetAgentArgs, opts?: pulumi.InvokeOptions): Promise<GetAgentResult>;
export interface GetAgentArgs {
    /**
     * Identifier for a resource.
     */
    agentId: string;
}
export interface GetAgentResult {
    /**
     * List of ActionGroups
     */
    readonly actionGroups?: outputs.bedrock.AgentActionGroup[];
    /**
     * Arn representation of the Agent.
     */
    readonly agentArn?: string;
    /**
     * The agent's collaboration settings.
     */
    readonly agentCollaboration?: enums.bedrock.AgentCollaboration;
    /**
     * List of Agent Collaborators
     */
    readonly agentCollaborators?: outputs.bedrock.AgentCollaborator[];
    /**
     * Identifier for a resource.
     */
    readonly agentId?: string;
    /**
     * Name for a resource.
     */
    readonly agentName?: string;
    /**
     * ARN of a IAM role.
     */
    readonly agentResourceRoleArn?: string;
    /**
     * The status of the agent and whether it is ready for use. The following statuses are possible:
     *
     * - CREATING – The agent is being created.
     * - PREPARING – The agent is being prepared.
     * - PREPARED – The agent is prepared and ready to be invoked.
     * - NOT_PREPARED – The agent has been created but not yet prepared.
     * - FAILED – The agent API operation failed.
     * - UPDATING – The agent is being updated.
     * - DELETING – The agent is being deleted.
     */
    readonly agentStatus?: enums.bedrock.AgentStatus;
    /**
     * Draft Agent Version.
     */
    readonly agentVersion?: string;
    /**
     * Time Stamp.
     */
    readonly createdAt?: string;
    /**
     * Contains custom orchestration configurations for the agent.
     */
    readonly customOrchestration?: outputs.bedrock.AgentCustomOrchestration;
    /**
     * A KMS key ARN
     */
    readonly customerEncryptionKeyArn?: string;
    /**
     * Description of the Resource.
     */
    readonly description?: string;
    /**
     * Failure Reasons for Error.
     */
    readonly failureReasons?: string[];
    /**
     * The foundation model used for orchestration by the agent.
     */
    readonly foundationModel?: string;
    /**
     * Details about the guardrail associated with the agent.
     */
    readonly guardrailConfiguration?: outputs.bedrock.AgentGuardrailConfiguration;
    /**
     * Max Session Time.
     */
    readonly idleSessionTtlInSeconds?: number;
    /**
     * Instruction for the agent.
     */
    readonly instruction?: string;
    /**
     * List of Agent Knowledge Bases
     */
    readonly knowledgeBases?: outputs.bedrock.AgentKnowledgeBase[];
    /**
     * Contains memory configuration for the agent.
     */
    readonly memoryConfiguration?: outputs.bedrock.AgentMemoryConfiguration;
    /**
     * Specifies the orchestration strategy for the agent.
     */
    readonly orchestrationType?: enums.bedrock.AgentOrchestrationType;
    /**
     * Time Stamp.
     */
    readonly preparedAt?: string;
    /**
     * Contains configurations to override prompt templates in different parts of an agent sequence. For more information, see [Advanced prompts](https://docs.aws.amazon.com/bedrock/latest/userguide/advanced-prompts.html) .
     */
    readonly promptOverrideConfiguration?: outputs.bedrock.AgentPromptOverrideConfiguration;
    /**
     * The recommended actions users can take to resolve an error in failureReasons.
     */
    readonly recommendedActions?: string[];
    /**
     * Metadata that you can assign to a resource as key-value pairs. For more information, see the following resources:
     *
     * - [Tag naming limits and requirements](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-conventions)
     * - [Tagging best practices](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-best-practices)
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Metadata that you can assign to a resource as key-value pairs. For more information, see the following resources:
     *
     * - [Tag naming limits and requirements](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-conventions)
     * - [Tagging best practices](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-best-practices)
     */
    readonly testAliasTags?: {
        [key: string]: string;
    };
    /**
     * Time Stamp.
     */
    readonly updatedAt?: string;
}
/**
 * Definition of AWS::Bedrock::Agent Resource Type
 */
export declare function getAgentOutput(args: GetAgentOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAgentResult>;
export interface GetAgentOutputArgs {
    /**
     * Identifier for a resource.
     */
    agentId: pulumi.Input<string>;
}
