import * as pulumi from "@pulumi/pulumi";
/**
 * Resource schema for AWS::Cassandra::Type
 */
export declare function getType(args: GetTypeArgs, opts?: pulumi.InvokeOptions): Promise<GetTypeResult>;
export interface GetTypeArgs {
    /**
     * Name of the Keyspace which contains the User-Defined Type.
     */
    keyspaceName: string;
    /**
     * Name of the User-Defined Type.
     */
    typeName: string;
}
export interface GetTypeResult {
    /**
     * List of parent User-Defined Types that directly reference the User-Defined Type in their fields.
     */
    readonly directParentTypes?: string[];
    /**
     * List of Tables that directly reference the User-Defined Type in their columns.
     */
    readonly directReferringTables?: string[];
    /**
     * ARN of the Keyspace which contains the User-Defined Type.
     */
    readonly keyspaceArn?: string;
    /**
     * Timestamp of the last time the User-Defined Type's meta data was modified.
     */
    readonly lastModifiedTimestamp?: number;
    /**
     * Maximum nesting depth of the User-Defined Type across the field types.
     */
    readonly maxNestingDepth?: number;
}
/**
 * Resource schema for AWS::Cassandra::Type
 */
export declare function getTypeOutput(args: GetTypeOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTypeResult>;
export interface GetTypeOutputArgs {
    /**
     * Name of the Keyspace which contains the User-Defined Type.
     */
    keyspaceName: pulumi.Input<string>;
    /**
     * Name of the User-Defined Type.
     */
    typeName: pulumi.Input<string>;
}
