import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * This is a CloudFormation resource for the first-party AWS::Hooks::LambdaHook.
 */
export declare function getLambdaHook(args: GetLambdaHookArgs, opts?: pulumi.InvokeOptions): Promise<GetLambdaHookResult>;
export interface GetLambdaHookArgs {
    /**
     * The Amazon Resource Name (ARN) of the activated hook
     */
    hookArn: string;
}
export interface GetLambdaHookResult {
    /**
     * The execution role ARN assumed by Hooks to invoke Lambda.
     */
    readonly executionRole?: string;
    /**
     * Attribute to specify CloudFormation behavior on hook failure.
     */
    readonly failureMode?: enums.cloudformation.LambdaHookFailureMode;
    /**
     * The Amazon Resource Name (ARN) of the activated hook
     */
    readonly hookArn?: string;
    /**
     * Attribute to specify which stacks this hook applies to or should get invoked for
     */
    readonly hookStatus?: enums.cloudformation.LambdaHookHookStatus;
    /**
     * Amazon Resource Name (ARN), Partial ARN, name, version, or alias of the Lambda function to invoke with this hook.
     */
    readonly lambdaFunction?: string;
    /**
     * Filters to allow hooks to target specific stack attributes
     */
    readonly stackFilters?: outputs.cloudformation.StackFiltersProperties;
    /**
     * Attribute to specify which targets should invoke the hook
     */
    readonly targetFilters?: outputs.cloudformation.TargetFilters0Properties | outputs.cloudformation.TargetFilters1Properties;
    /**
     * Which operations should this Hook run against? Resource changes, stacks or change sets.
     */
    readonly targetOperations?: enums.cloudformation.LambdaHookTargetOperation[];
}
/**
 * This is a CloudFormation resource for the first-party AWS::Hooks::LambdaHook.
 */
export declare function getLambdaHookOutput(args: GetLambdaHookOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetLambdaHookResult>;
export interface GetLambdaHookOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the activated hook
     */
    hookArn: pulumi.Input<string>;
}
