import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Config::ConfigurationAggregator
 */
export declare class ConfigurationAggregator extends pulumi.CustomResource {
    /**
     * Get an existing ConfigurationAggregator resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ConfigurationAggregator;
    /**
     * Returns true if the given object is an instance of ConfigurationAggregator.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ConfigurationAggregator;
    /**
     * Provides a list of source accounts and regions to be aggregated.
     */
    readonly accountAggregationSources: pulumi.Output<outputs.configuration.ConfigurationAggregatorAccountAggregationSource[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the aggregator.
     */
    readonly configurationAggregatorArn: pulumi.Output<string>;
    /**
     * The name of the aggregator.
     */
    readonly configurationAggregatorName: pulumi.Output<string | undefined>;
    /**
     * Provides an organization and list of regions to be aggregated.
     */
    readonly organizationAggregationSource: pulumi.Output<outputs.configuration.ConfigurationAggregatorOrganizationAggregationSource | undefined>;
    /**
     * The tags for the configuration aggregator.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ConfigurationAggregator resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ConfigurationAggregatorArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ConfigurationAggregator resource.
 */
export interface ConfigurationAggregatorArgs {
    /**
     * Provides a list of source accounts and regions to be aggregated.
     */
    accountAggregationSources?: pulumi.Input<pulumi.Input<inputs.configuration.ConfigurationAggregatorAccountAggregationSourceArgs>[]>;
    /**
     * The name of the aggregator.
     */
    configurationAggregatorName?: pulumi.Input<string>;
    /**
     * Provides an organization and list of regions to be aggregated.
     */
    organizationAggregationSource?: pulumi.Input<inputs.configuration.ConfigurationAggregatorOrganizationAggregationSourceArgs>;
    /**
     * The tags for the configuration aggregator.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
