import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Creates an evaluation form for the specified CON instance.
 */
export declare function getEvaluationForm(args: GetEvaluationFormArgs, opts?: pulumi.InvokeOptions): Promise<GetEvaluationFormResult>;
export interface GetEvaluationFormArgs {
    /**
     * The Amazon Resource Name (ARN) of the evaluation form.
     */
    evaluationFormArn: string;
}
export interface GetEvaluationFormResult {
    /**
     * The description of the evaluation form.
     *   *Length Constraints*: Minimum length of 0. Maximum length of 1024.
     */
    readonly description?: string;
    /**
     * The Amazon Resource Name (ARN) of the evaluation form.
     */
    readonly evaluationFormArn?: string;
    /**
     * The identifier of the Amazon Connect instance.
     */
    readonly instanceArn?: string;
    /**
     * Items that are part of the evaluation form. The total number of sections and questions must not exceed 100 each. Questions must be contained in a section.
     *   *Minimum size*: 1
     *   *Maximum size*: 100
     */
    readonly items?: outputs.connect.EvaluationFormBaseItem[];
    /**
     * A scoring strategy of the evaluation form.
     */
    readonly scoringStrategy?: outputs.connect.EvaluationFormScoringStrategy;
    /**
     * The status of the evaluation form.
     *   *Allowed values*: ``DRAFT`` | ``ACTIVE``
     */
    readonly status?: enums.connect.EvaluationFormStatus;
    /**
     * The tags used to organize, track, or control access for this resource. For example, { "tags": {"key1":"value1", "key2":"value2"} }.
     */
    readonly tags?: outputs.Tag[];
    /**
     * A title of the evaluation form.
     */
    readonly title?: string;
}
/**
 * Creates an evaluation form for the specified CON instance.
 */
export declare function getEvaluationFormOutput(args: GetEvaluationFormOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEvaluationFormResult>;
export interface GetEvaluationFormOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the evaluation form.
     */
    evaluationFormArn: pulumi.Input<string>;
}
