import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Connect::SecurityProfile
 */
export declare function getSecurityProfile(args: GetSecurityProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetSecurityProfileResult>;
export interface GetSecurityProfileArgs {
    /**
     * The Amazon Resource Name (ARN) for the security profile.
     */
    securityProfileArn: string;
}
export interface GetSecurityProfileResult {
    /**
     * The identifier of the hierarchy group that a security profile uses to restrict access to resources in Amazon Connect.
     */
    readonly allowedAccessControlHierarchyGroupId?: string;
    /**
     * The list of tags that a security profile uses to restrict access to resources in Amazon Connect.
     */
    readonly allowedAccessControlTags?: outputs.connect.SecurityProfileTag[];
    /**
     * A list of third-party applications that the security profile will give access to.
     */
    readonly applications?: outputs.connect.SecurityProfileApplication[];
    /**
     * The description of the security profile.
     */
    readonly description?: string;
    /**
     * The list of resources that a security profile applies hierarchy restrictions to in Amazon Connect.
     */
    readonly hierarchyRestrictedResources?: string[];
    /**
     * The AWS Region where this resource was last modified.
     */
    readonly lastModifiedRegion?: string;
    /**
     * The timestamp when this resource was last modified.
     */
    readonly lastModifiedTime?: number;
    /**
     * Permissions assigned to the security profile.
     */
    readonly permissions?: string[];
    /**
     * The Amazon Resource Name (ARN) for the security profile.
     */
    readonly securityProfileArn?: string;
    /**
     * The list of resources that a security profile applies tag restrictions to in Amazon Connect.
     */
    readonly tagRestrictedResources?: string[];
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::Connect::SecurityProfile
 */
export declare function getSecurityProfileOutput(args: GetSecurityProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSecurityProfileResult>;
export interface GetSecurityProfileOutputArgs {
    /**
     * The Amazon Resource Name (ARN) for the security profile.
     */
    securityProfileArn: pulumi.Input<string>;
}
