import * as pulumi from "@pulumi/pulumi";
/**
 * A domain unit enables you to easily organize your assets and other domain entities under specific business units and teams.
 */
export declare class DomainUnit extends pulumi.CustomResource {
    /**
     * Get an existing DomainUnit resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DomainUnit;
    /**
     * Returns true if the given object is an instance of DomainUnit.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DomainUnit;
    /**
     * The ID of the domain unit.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The timestamp at which the domain unit was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The description of the domain unit.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ID of the domain where the domain unit was created.
     */
    readonly domainId: pulumi.Output<string>;
    /**
     * The ID of the domain where you want to create a domain unit.
     */
    readonly domainIdentifier: pulumi.Output<string>;
    /**
     * The identifier of the domain unit that you want to get.
     */
    readonly identifier: pulumi.Output<string>;
    /**
     * The timestamp at which the domain unit was last updated.
     */
    readonly lastUpdatedAt: pulumi.Output<string>;
    /**
     * The name of the domain unit.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ID of the parent domain unit.
     */
    readonly parentDomainUnitId: pulumi.Output<string>;
    /**
     * The ID of the parent domain unit.
     */
    readonly parentDomainUnitIdentifier: pulumi.Output<string>;
    /**
     * Create a DomainUnit resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DomainUnitArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DomainUnit resource.
 */
export interface DomainUnitArgs {
    /**
     * The description of the domain unit.
     */
    description?: pulumi.Input<string>;
    /**
     * The ID of the domain where you want to create a domain unit.
     */
    domainIdentifier: pulumi.Input<string>;
    /**
     * The name of the domain unit.
     */
    name?: pulumi.Input<string>;
    /**
     * The ID of the parent domain unit.
     */
    parentDomainUnitIdentifier: pulumi.Input<string>;
}
