import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Schema of AWS::EC2::IPAM Type
 */
export declare function getIpam(args: GetIpamArgs, opts?: pulumi.InvokeOptions): Promise<GetIpamResult>;
export interface GetIpamArgs {
    /**
     * Id of the IPAM.
     */
    ipamId: string;
}
export interface GetIpamResult {
    /**
     * The Amazon Resource Name (ARN) of the IPAM.
     */
    readonly arn?: string;
    /**
     * The Id of the default association to the default resource discovery, created with this IPAM.
     */
    readonly defaultResourceDiscoveryAssociationId?: string;
    /**
     * The Id of the default resource discovery, created with this IPAM.
     */
    readonly defaultResourceDiscoveryId?: string;
    /**
     * A set of organizational unit (OU) exclusions for the default resource discovery, created with this IPAM.
     */
    readonly defaultResourceDiscoveryOrganizationalUnitExclusions?: outputs.ec2.IpamOrganizationalUnitExclusion[];
    /**
     * The description for the IPAM.
     */
    readonly description?: string;
    /**
     * Enable provisioning of GUA space in private pools.
     */
    readonly enablePrivateGua?: boolean;
    /**
     * Id of the IPAM.
     */
    readonly ipamId?: string;
    /**
     * The regions IPAM is enabled for. Allows pools to be created in these regions, as well as enabling monitoring
     */
    readonly operatingRegions?: outputs.ec2.IpamOperatingRegion[];
    /**
     * The Id of the default scope for publicly routable IP space, created with this IPAM.
     */
    readonly privateDefaultScopeId?: string;
    /**
     * The Id of the default scope for publicly routable IP space, created with this IPAM.
     */
    readonly publicDefaultScopeId?: string;
    /**
     * The count of resource discoveries associated with this IPAM.
     */
    readonly resourceDiscoveryAssociationCount?: number;
    /**
     * The number of scopes that currently exist in this IPAM.
     */
    readonly scopeCount?: number;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The tier of the IPAM.
     */
    readonly tier?: enums.ec2.IpamTier;
}
/**
 * Resource Schema of AWS::EC2::IPAM Type
 */
export declare function getIpamOutput(args: GetIpamOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIpamResult>;
export interface GetIpamOutputArgs {
    /**
     * Id of the IPAM.
     */
    ipamId: pulumi.Input<string>;
}
