import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Schema of AWS::EC2::IPAMResourceDiscoveryAssociation Type
 */
export declare class IpamResourceDiscoveryAssociation extends pulumi.CustomResource {
    /**
     * Get an existing IpamResourceDiscoveryAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): IpamResourceDiscoveryAssociation;
    /**
     * Returns true if the given object is an instance of IpamResourceDiscoveryAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IpamResourceDiscoveryAssociation;
    /**
     * Arn of the IPAM.
     */
    readonly ipamArn: pulumi.Output<string>;
    /**
     * The Id of the IPAM this Resource Discovery is associated to.
     */
    readonly ipamId: pulumi.Output<string>;
    /**
     * The home region of the IPAM.
     */
    readonly ipamRegion: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the resource discovery association is a part of.
     */
    readonly ipamResourceDiscoveryAssociationArn: pulumi.Output<string>;
    /**
     * Id of the IPAM Resource Discovery Association.
     */
    readonly ipamResourceDiscoveryAssociationId: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the IPAM Resource Discovery Association.
     */
    readonly ipamResourceDiscoveryId: pulumi.Output<string>;
    /**
     * If the Resource Discovery Association exists due as part of CreateIpam.
     */
    readonly isDefault: pulumi.Output<boolean>;
    /**
     * The AWS Account ID for the account where the shared IPAM exists.
     */
    readonly ownerId: pulumi.Output<string>;
    /**
     * The status of the resource discovery.
     */
    readonly resourceDiscoveryStatus: pulumi.Output<string>;
    /**
     * The operational state of the Resource Discovery Association. Related to Create/Delete activities.
     */
    readonly state: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a IpamResourceDiscoveryAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IpamResourceDiscoveryAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a IpamResourceDiscoveryAssociation resource.
 */
export interface IpamResourceDiscoveryAssociationArgs {
    /**
     * The Id of the IPAM this Resource Discovery is associated to.
     */
    ipamId: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the IPAM Resource Discovery Association.
     */
    ipamResourceDiscoveryId: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
