import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Attaches an elastic network interface (ENI) to an Amazon EC2 instance. You can use this resource type to attach additional network interfaces to an instance without interruption.
 */
export declare class NetworkInterfaceAttachment extends pulumi.CustomResource {
    /**
     * Get an existing NetworkInterfaceAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): NetworkInterfaceAttachment;
    /**
     * Returns true if the given object is an instance of NetworkInterfaceAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is NetworkInterfaceAttachment;
    /**
     * The ID of the network interface attachment.
     */
    readonly attachmentId: pulumi.Output<string>;
    /**
     * Whether to delete the network interface when the instance terminates. By default, this value is set to ``true``.
     */
    readonly deleteOnTermination: pulumi.Output<boolean | undefined>;
    /**
     * The network interface's position in the attachment order. For example, the first attached network interface has a ``DeviceIndex`` of 0.
     */
    readonly deviceIndex: pulumi.Output<string>;
    /**
     * Configures ENA Express for the network interface that this action attaches to the instance.
     */
    readonly enaSrdSpecification: pulumi.Output<outputs.ec2.NetworkInterfaceAttachmentEnaSrdSpecification | undefined>;
    /**
     * The ID of the instance to which you will attach the ENI.
     */
    readonly instanceId: pulumi.Output<string>;
    /**
     * The ID of the ENI that you want to attach.
     */
    readonly networkInterfaceId: pulumi.Output<string>;
    /**
     * Create a NetworkInterfaceAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: NetworkInterfaceAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a NetworkInterfaceAttachment resource.
 */
export interface NetworkInterfaceAttachmentArgs {
    /**
     * Whether to delete the network interface when the instance terminates. By default, this value is set to ``true``.
     */
    deleteOnTermination?: pulumi.Input<boolean>;
    /**
     * The network interface's position in the attachment order. For example, the first attached network interface has a ``DeviceIndex`` of 0.
     */
    deviceIndex: pulumi.Input<string>;
    /**
     * Configures ENA Express for the network interface that this action attaches to the instance.
     */
    enaSrdSpecification?: pulumi.Input<inputs.ec2.NetworkInterfaceAttachmentEnaSrdSpecificationArgs>;
    /**
     * The ID of the instance to which you will attach the ENI.
     */
    instanceId: pulumi.Input<string>;
    /**
     * The ID of the ENI that you want to attach.
     */
    networkInterfaceId: pulumi.Input<string>;
}
