import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::EC2::TransitGatewayRoute
 */
export declare class TransitGatewayRoute extends pulumi.CustomResource {
    /**
     * Get an existing TransitGatewayRoute resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TransitGatewayRoute;
    /**
     * Returns true if the given object is an instance of TransitGatewayRoute.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TransitGatewayRoute;
    /**
     * Indicates whether to drop traffic that matches this route.
     */
    readonly blackhole: pulumi.Output<boolean | undefined>;
    /**
     * The CIDR range used for destination matches. Routing decisions are based on the most specific match.
     */
    readonly destinationCidrBlock: pulumi.Output<string>;
    /**
     * The ID of transit gateway attachment.
     */
    readonly transitGatewayAttachmentId: pulumi.Output<string | undefined>;
    /**
     * The ID of transit gateway route table.
     */
    readonly transitGatewayRouteTableId: pulumi.Output<string>;
    /**
     * Create a TransitGatewayRoute resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TransitGatewayRouteArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TransitGatewayRoute resource.
 */
export interface TransitGatewayRouteArgs {
    /**
     * Indicates whether to drop traffic that matches this route.
     */
    blackhole?: pulumi.Input<boolean>;
    /**
     * The CIDR range used for destination matches. Routing decisions are based on the most specific match.
     */
    destinationCidrBlock: pulumi.Input<string>;
    /**
     * The ID of transit gateway attachment.
     */
    transitGatewayAttachmentId?: pulumi.Input<string>;
    /**
     * The ID of transit gateway route table.
     */
    transitGatewayRouteTableId: pulumi.Input<string>;
}
