import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The AWS::ECR::RegistryScanningConfiguration controls the scanning configuration for an Amazon Elastic Container Registry (Amazon Private ECR). For more information, see https://docs.aws.amazon.com/AmazonECR/latest/userguide/image-scanning.html
 */
export declare function getRegistryScanningConfiguration(args: GetRegistryScanningConfigurationArgs, opts?: pulumi.InvokeOptions): Promise<GetRegistryScanningConfigurationResult>;
export interface GetRegistryScanningConfigurationArgs {
    /**
     * The account ID of the destination registry.
     */
    registryId: string;
}
export interface GetRegistryScanningConfigurationResult {
    /**
     * The account ID of the destination registry.
     */
    readonly registryId?: string;
    /**
     * The scanning rules associated with the registry.
     */
    readonly rules?: outputs.ecr.RegistryScanningConfigurationScanningRule[];
    /**
     * The type of scanning configured for the registry.
     */
    readonly scanType?: enums.ecr.RegistryScanningConfigurationScanType;
}
/**
 * The AWS::ECR::RegistryScanningConfiguration controls the scanning configuration for an Amazon Elastic Container Registry (Amazon Private ECR). For more information, see https://docs.aws.amazon.com/AmazonECR/latest/userguide/image-scanning.html
 */
export declare function getRegistryScanningConfigurationOutput(args: GetRegistryScanningConfigurationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRegistryScanningConfigurationResult>;
export interface GetRegistryScanningConfigurationOutputArgs {
    /**
     * The account ID of the destination registry.
     */
    registryId: pulumi.Input<string>;
}
