import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * IdMappingWorkflow defined in AWS Entity Resolution service
 */
export declare function getIdMappingWorkflow(args: GetIdMappingWorkflowArgs, opts?: pulumi.InvokeOptions): Promise<GetIdMappingWorkflowResult>;
export interface GetIdMappingWorkflowArgs {
    /**
     * The name of the IdMappingWorkflow
     */
    workflowName: string;
}
export interface GetIdMappingWorkflowResult {
    readonly createdAt?: string;
    /**
     * The description of the IdMappingWorkflow
     */
    readonly description?: string;
    /**
     * An object which defines the ID mapping technique and any additional configurations.
     */
    readonly idMappingTechniques?: outputs.entityresolution.IdMappingWorkflowIdMappingTechniques;
    /**
     * A list of `InputSource` objects, which have the fields `InputSourceARN` and `SchemaName` .
     */
    readonly inputSourceConfig?: outputs.entityresolution.IdMappingWorkflowInputSource[];
    /**
     * A list of `IdMappingWorkflowOutputSource` objects, each of which contains fields `OutputS3Path` and `Output` .
     */
    readonly outputSourceConfig?: outputs.entityresolution.IdMappingWorkflowOutputSource[];
    /**
     * The Amazon Resource Name (ARN) of the IAM role. AWS Entity Resolution assumes this role to create resources on your behalf as part of workflow execution.
     */
    readonly roleArn?: string;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    readonly tags?: outputs.Tag[];
    readonly updatedAt?: string;
    readonly workflowArn?: string;
}
/**
 * IdMappingWorkflow defined in AWS Entity Resolution service
 */
export declare function getIdMappingWorkflowOutput(args: GetIdMappingWorkflowOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIdMappingWorkflowResult>;
export interface GetIdMappingWorkflowOutputArgs {
    /**
     * The name of the IdMappingWorkflow
     */
    workflowName: pulumi.Input<string>;
}
