import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Evidently::Feature.
 */
export declare function getFeature(args: GetFeatureArgs, opts?: pulumi.InvokeOptions): Promise<GetFeatureResult>;
export interface GetFeatureArgs {
    /**
     * The ARN of the feature. For example, `arn:aws:evidently:us-west-2:0123455678912:project/myProject/feature/myFeature` .
     */
    arn: string;
}
export interface GetFeatureResult {
    /**
     * The ARN of the feature. For example, `arn:aws:evidently:us-west-2:0123455678912:project/myProject/feature/myFeature` .
     */
    readonly arn?: string;
    /**
     * The name of the variation to use as the default variation. The default variation is served to users who are not allocated to any ongoing launches or experiments of this feature.
     *
     * This variation must also be listed in the `Variations` structure.
     *
     * If you omit `DefaultVariation` , the first variation listed in the `Variations` structure is used as the default variation.
     */
    readonly defaultVariation?: string;
    /**
     * An optional description of the feature.
     */
    readonly description?: string;
    /**
     * Specify users that should always be served a specific variation of a feature. Each user is specified by a key-value pair . For each key, specify a user by entering their user ID, account ID, or some other identifier. For the value, specify the name of the variation that they are to be served.
     */
    readonly entityOverrides?: outputs.evidently.FeatureEntityOverride[];
    /**
     * Specify `ALL_RULES` to activate the traffic allocation specified by any ongoing launches or experiments. Specify `DEFAULT_VARIATION` to serve the default variation to all users instead.
     */
    readonly evaluationStrategy?: enums.evidently.FeatureEvaluationStrategy;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * An array of structures that contain the configuration of the feature's different variations.
     *
     * Each `VariationObject` in the `Variations` array for a feature must have the same type of value ( `BooleanValue` , `DoubleValue` , `LongValue` or `StringValue` ).
     */
    readonly variations?: outputs.evidently.FeatureVariationObject[];
}
/**
 * Resource Type definition for AWS::Evidently::Feature.
 */
export declare function getFeatureOutput(args: GetFeatureOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetFeatureResult>;
export interface GetFeatureOutputArgs {
    /**
     * The ARN of the feature. For example, `arn:aws:evidently:us-west-2:0123455678912:project/myProject/feature/myFeature` .
     */
    arn: pulumi.Input<string>;
}
