import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Represents a dataset group that holds a collection of related datasets
 */
export declare function getDatasetGroup(args: GetDatasetGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetDatasetGroupResult>;
export interface GetDatasetGroupArgs {
    /**
     * The Amazon Resource Name (ARN) of the dataset group to delete.
     */
    datasetGroupArn: string;
}
export interface GetDatasetGroupResult {
    /**
     * An array of Amazon Resource Names (ARNs) of the datasets that you want to include in the dataset group.
     */
    readonly datasetArns?: string[];
    /**
     * The Amazon Resource Name (ARN) of the dataset group to delete.
     */
    readonly datasetGroupArn?: string;
    /**
     * The domain associated with the dataset group. When you add a dataset to a dataset group, this value and the value specified for the Domain parameter of the CreateDataset operation must match.
     */
    readonly domain?: enums.forecast.DatasetGroupDomain;
    /**
     * The tags of Application Insights application.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Represents a dataset group that holds a collection of related datasets
 */
export declare function getDatasetGroupOutput(args: GetDatasetGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDatasetGroupResult>;
export interface GetDatasetGroupOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the dataset group to delete.
     */
    datasetGroupArn: pulumi.Input<string>;
}
