import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * This resource represents an individual schema version of a schema defined in Glue Schema Registry.
 */
export declare class SchemaVersion extends pulumi.CustomResource {
    /**
     * Get an existing SchemaVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SchemaVersion;
    /**
     * Returns true if the given object is an instance of SchemaVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SchemaVersion;
    /**
     * The schema that includes the schema version.
     */
    readonly schema: pulumi.Output<outputs.glue.SchemaVersionSchema>;
    /**
     * Complete definition of the schema in plain-text.
     */
    readonly schemaDefinition: pulumi.Output<string>;
    /**
     * Represents the version ID associated with the schema version.
     */
    readonly versionId: pulumi.Output<string>;
    /**
     * Create a SchemaVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SchemaVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SchemaVersion resource.
 */
export interface SchemaVersionArgs {
    /**
     * The schema that includes the schema version.
     */
    schema: pulumi.Input<inputs.glue.SchemaVersionSchemaArgs>;
    /**
     * Complete definition of the schema in plain-text.
     */
    schemaDefinition: pulumi.Input<string>;
}
