import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * A custom metric published by your devices to Device Defender.
 */
export declare function getCustomMetric(args: GetCustomMetricArgs, opts?: pulumi.InvokeOptions): Promise<GetCustomMetricResult>;
export interface GetCustomMetricArgs {
    /**
     * The name of the custom metric. This will be used in the metric report submitted from the device/thing. Shouldn't begin with aws: . Cannot be updated once defined.
     */
    metricName: string;
}
export interface GetCustomMetricResult {
    /**
     * Field represents a friendly name in the console for the custom metric; it doesn't have to be unique. Don't use this name as the metric identifier in the device metric report. Can be updated once defined.
     */
    readonly displayName?: string;
    /**
     * The Amazon Resource Number (ARN) of the custom metric.
     */
    readonly metricArn?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * A custom metric published by your devices to Device Defender.
 */
export declare function getCustomMetricOutput(args: GetCustomMetricOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCustomMetricResult>;
export interface GetCustomMetricOutputArgs {
    /**
     * The name of the custom metric. This will be used in the metric report submitted from the device/thing. Shouldn't begin with aws: . Cannot be updated once defined.
     */
    metricName: pulumi.Input<string>;
}
