import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Mitigation actions can be used to take actions to mitigate issues that were found in an Audit finding or Detect violation.
 */
export declare function getMitigationAction(args: GetMitigationActionArgs, opts?: pulumi.InvokeOptions): Promise<GetMitigationActionResult>;
export interface GetMitigationActionArgs {
    /**
     * A unique identifier for the mitigation action.
     */
    actionName: string;
}
export interface GetMitigationActionResult {
    /**
     * The set of parameters for this mitigation action. The parameters vary, depending on the kind of action you apply.
     */
    readonly actionParams?: outputs.iot.MitigationActionActionParams;
    /**
     * The Amazon Resource Name (ARN) of the mitigation action.
     */
    readonly mitigationActionArn?: string;
    /**
     * The ID of the mitigation action.
     */
    readonly mitigationActionId?: string;
    /**
     * The IAM role ARN used to apply this mitigation action.
     */
    readonly roleArn?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Mitigation actions can be used to take actions to mitigate issues that were found in an Audit finding or Detect violation.
 */
export declare function getMitigationActionOutput(args: GetMitigationActionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMitigationActionResult>;
export interface GetMitigationActionOutputArgs {
    /**
     * A unique identifier for the mitigation action.
     */
    actionName: pulumi.Input<string>;
}
