import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::IVS::PublicKey
 */
export declare class PublicKey extends pulumi.CustomResource {
    /**
     * Get an existing PublicKey resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): PublicKey;
    /**
     * Returns true if the given object is an instance of PublicKey.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PublicKey;
    /**
     * Key-pair identifier.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Key-pair identifier.
     */
    readonly fingerprint: pulumi.Output<string>;
    /**
     * Name of the public key to be imported. The value does not need to be unique.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The public portion of a customer-generated key pair. This field is required to create the AWS::IVS::PublicKey resource.
     */
    readonly publicKeyMaterial: pulumi.Output<string | undefined>;
    /**
     * A list of key-value pairs that contain metadata for the asset model.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a PublicKey resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: PublicKeyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a PublicKey resource.
 */
export interface PublicKeyArgs {
    /**
     * Name of the public key to be imported. The value does not need to be unique.
     */
    name?: pulumi.Input<string>;
    /**
     * The public portion of a customer-generated key pair. This field is required to create the AWS::IVS::PublicKey resource.
     */
    publicKeyMaterial?: pulumi.Input<string>;
    /**
     * A list of key-value pairs that contain metadata for the asset model.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
