import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * A KendraRanking Rescore execution plan
 */
export declare class ExecutionPlan extends pulumi.CustomResource {
    /**
     * Get an existing ExecutionPlan resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ExecutionPlan;
    /**
     * Returns true if the given object is an instance of ExecutionPlan.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ExecutionPlan;
    /**
     * The Amazon Resource Name (ARN) of the rescore execution plan.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The identifier of the rescore execution plan.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Capacity units
     */
    readonly capacityUnits: pulumi.Output<outputs.kendraranking.ExecutionPlanCapacityUnitsConfiguration | undefined>;
    /**
     * A description for the execution plan
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * A name for the rescore execution plan.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Tags for labeling the execution plan
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ExecutionPlan resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ExecutionPlanArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ExecutionPlan resource.
 */
export interface ExecutionPlanArgs {
    /**
     * Capacity units
     */
    capacityUnits?: pulumi.Input<inputs.kendraranking.ExecutionPlanCapacityUnitsConfigurationArgs>;
    /**
     * A description for the execution plan
     */
    description?: pulumi.Input<string>;
    /**
     * A name for the rescore execution plan.
     */
    name?: pulumi.Input<string>;
    /**
     * Tags for labeling the execution plan
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
