import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::Lightsail::StaticIp
 */
export declare class StaticIp extends pulumi.CustomResource {
    /**
     * Get an existing StaticIp resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): StaticIp;
    /**
     * Returns true if the given object is an instance of StaticIp.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is StaticIp;
    /**
     * The instance where the static IP is attached.
     */
    readonly attachedTo: pulumi.Output<string | undefined>;
    /**
     * The static IP address.
     */
    readonly ipAddress: pulumi.Output<string>;
    /**
     * A Boolean value indicating whether the static IP is attached.
     */
    readonly isAttached: pulumi.Output<boolean>;
    /**
     * The Amazon Resource Name (ARN) of the static IP (for example, `arn:aws:lightsail:us-east-2:123456789101:StaticIp/244ad76f-8aad-4741-809f-12345EXAMPLE` ).
     */
    readonly staticIpArn: pulumi.Output<string>;
    /**
     * The name of the static IP address.
     */
    readonly staticIpName: pulumi.Output<string>;
    /**
     * Create a StaticIp resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: StaticIpArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a StaticIp resource.
 */
export interface StaticIpArgs {
    /**
     * The instance where the static IP is attached.
     */
    attachedTo?: pulumi.Input<string>;
    /**
     * The name of the static IP address.
     */
    staticIpName?: pulumi.Input<string>;
}
