import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::MediaConnect::BridgeSource
 */
export declare class BridgeSource extends pulumi.CustomResource {
    /**
     * Get an existing BridgeSource resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): BridgeSource;
    /**
     * Returns true if the given object is an instance of BridgeSource.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is BridgeSource;
    /**
     * The Amazon Resource Number (ARN) of the bridge.
     */
    readonly bridgeArn: pulumi.Output<string>;
    /**
     * The source of the flow.
     */
    readonly flowSource: pulumi.Output<outputs.mediaconnect.BridgeSourceBridgeFlowSource | undefined>;
    /**
     * The name of the source.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The source of the network.
     */
    readonly networkSource: pulumi.Output<outputs.mediaconnect.BridgeSourceBridgeNetworkSource | undefined>;
    /**
     * Create a BridgeSource resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BridgeSourceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a BridgeSource resource.
 */
export interface BridgeSourceArgs {
    /**
     * The Amazon Resource Number (ARN) of the bridge.
     */
    bridgeArn: pulumi.Input<string>;
    /**
     * The source of the flow.
     */
    flowSource?: pulumi.Input<inputs.mediaconnect.BridgeSourceBridgeFlowSourceArgs>;
    /**
     * The name of the source.
     */
    name?: pulumi.Input<string>;
    /**
     * The source of the network.
     */
    networkSource?: pulumi.Input<inputs.mediaconnect.BridgeSourceBridgeNetworkSourceArgs>;
}
