import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::MSK::ServerlessCluster
 */
export declare class ServerlessCluster extends pulumi.CustomResource {
    /**
     * Get an existing ServerlessCluster resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ServerlessCluster;
    /**
     * Returns true if the given object is an instance of ServerlessCluster.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServerlessCluster;
    /**
     * The Amazon Resource Name (ARN) of the MSK cluster.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Includes all client authentication related information.
     */
    readonly clientAuthentication: pulumi.Output<outputs.msk.ServerlessClusterClientAuthentication>;
    /**
     * The name of the cluster.
     */
    readonly clusterName: pulumi.Output<string>;
    /**
     * A key-value pair to associate with a resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * VPC configuration information for the serverless cluster.
     */
    readonly vpcConfigs: pulumi.Output<outputs.msk.ServerlessClusterVpcConfig[]>;
    /**
     * Create a ServerlessCluster resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ServerlessClusterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ServerlessCluster resource.
 */
export interface ServerlessClusterArgs {
    /**
     * Includes all client authentication related information.
     */
    clientAuthentication: pulumi.Input<inputs.msk.ServerlessClusterClientAuthenticationArgs>;
    /**
     * The name of the cluster.
     */
    clusterName?: pulumi.Input<string>;
    /**
     * A key-value pair to associate with a resource.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * VPC configuration information for the serverless cluster.
     */
    vpcConfigs: pulumi.Input<pulumi.Input<inputs.msk.ServerlessClusterVpcConfigArgs>[]>;
}
