import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::NetworkManager::Site type describes a site.
 */
export declare function getSite(args: GetSiteArgs, opts?: pulumi.InvokeOptions): Promise<GetSiteResult>;
export interface GetSiteArgs {
    /**
     * The ID of the global network.
     */
    globalNetworkId: string;
    /**
     * The ID of the site.
     */
    siteId: string;
}
export interface GetSiteResult {
    /**
     * The date and time that the device was created.
     */
    readonly createdAt?: string;
    /**
     * The description of the site.
     */
    readonly description?: string;
    /**
     * The location of the site.
     */
    readonly location?: outputs.networkmanager.SiteLocation;
    /**
     * The Amazon Resource Name (ARN) of the site.
     */
    readonly siteArn?: string;
    /**
     * The ID of the site.
     */
    readonly siteId?: string;
    /**
     * The state of the site.
     */
    readonly state?: string;
    /**
     * The tags for the site.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The AWS::NetworkManager::Site type describes a site.
 */
export declare function getSiteOutput(args: GetSiteOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSiteResult>;
export interface GetSiteOutputArgs {
    /**
     * The ID of the global network.
     */
    globalNetworkId: pulumi.Input<string>;
    /**
     * The ID of the site.
     */
    siteId: pulumi.Input<string>;
}
