import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Amazon OpenSearchServerless access policy resource
 */
export declare class AccessPolicy extends pulumi.CustomResource {
    /**
     * Get an existing AccessPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AccessPolicy;
    /**
     * Returns true if the given object is an instance of AccessPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AccessPolicy;
    /**
     * The description of the policy
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the policy
     */
    readonly name: pulumi.Output<string>;
    /**
     * The JSON policy document that is the content for the policy
     */
    readonly policy: pulumi.Output<string>;
    /**
     * The type of access policy. Currently the only option is `data` .
     */
    readonly type: pulumi.Output<enums.opensearchserverless.AccessPolicyType>;
    /**
     * Create a AccessPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AccessPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AccessPolicy resource.
 */
export interface AccessPolicyArgs {
    /**
     * The description of the policy
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the policy
     */
    name?: pulumi.Input<string>;
    /**
     * The JSON policy document that is the content for the policy
     */
    policy: pulumi.Input<string>;
    /**
     * The type of access policy. Currently the only option is `data` .
     */
    type: pulumi.Input<enums.opensearchserverless.AccessPolicyType>;
}
