import * as pulumi from "@pulumi/pulumi";
/**
 * Definition of AWS::PaymentCryptography::Alias Resource Type
 */
export declare class Alias extends pulumi.CustomResource {
    /**
     * Get an existing Alias resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Alias;
    /**
     * Returns true if the given object is an instance of Alias.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Alias;
    /**
     * A friendly name that you can use to refer to a key. The value must begin with `alias/` .
     *
     * > Do not include confidential or sensitive information in this field. This field may be displayed in plaintext in AWS CloudTrail logs and other output.
     */
    readonly aliasName: pulumi.Output<string>;
    /**
     * The `KeyARN` of the key associated with the alias.
     */
    readonly keyArn: pulumi.Output<string | undefined>;
    /**
     * Create a Alias resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AliasArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Alias resource.
 */
export interface AliasArgs {
    /**
     * A friendly name that you can use to refer to a key. The value must begin with `alias/` .
     *
     * > Do not include confidential or sensitive information in this field. This field may be displayed in plaintext in AWS CloudTrail logs and other output.
     */
    aliasName?: pulumi.Input<string>;
    /**
     * The `KeyARN` of the key associated with the alias.
     */
    keyArn?: pulumi.Input<string>;
}
