import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of the AWS::QuickSight::Folder Resource Type.
 */
export declare function getFolder(args: GetFolderArgs, opts?: pulumi.InvokeOptions): Promise<GetFolderResult>;
export interface GetFolderArgs {
    /**
     * The ID for the AWS account where you want to create the folder.
     */
    awsAccountId: string;
    /**
     * The ID of the folder.
     */
    folderId: string;
}
export interface GetFolderResult {
    /**
     * <p>The Amazon Resource Name (ARN) for the folder.</p>
     */
    readonly arn?: string;
    /**
     * <p>The time that the folder was created.</p>
     */
    readonly createdTime?: string;
    /**
     * <p>The time that the folder was last updated.</p>
     */
    readonly lastUpdatedTime?: string;
    /**
     * A display name for the folder.
     */
    readonly name?: string;
    /**
     * A structure that describes the principals and the resource-level permissions of a folder.
     *
     * To specify no permissions, omit `Permissions` .
     */
    readonly permissions?: outputs.quicksight.FolderResourcePermission[];
    /**
     * A list of tags for the folders that you want to apply overrides to.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Definition of the AWS::QuickSight::Folder Resource Type.
 */
export declare function getFolderOutput(args: GetFolderOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetFolderResult>;
export interface GetFolderOutputArgs {
    /**
     * The ID for the AWS account where you want to create the folder.
     */
    awsAccountId: pulumi.Input<string>;
    /**
     * The ID of the folder.
     */
    folderId: pulumi.Input<string>;
}
