import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of the AWS::QuickSight::VPCConnection Resource Type.
 */
export declare class VpcConnection extends pulumi.CustomResource {
    /**
     * Get an existing VpcConnection resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VpcConnection;
    /**
     * Returns true if the given object is an instance of VpcConnection.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcConnection;
    /**
     * <p>The Amazon Resource Name (ARN) of the VPC connection.</p>
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The availability status of the VPC connection.
     */
    readonly availabilityStatus: pulumi.Output<enums.quicksight.VpcConnectionVpcConnectionAvailabilityStatus | undefined>;
    /**
     * The AWS account ID of the account where you want to create a new VPC connection.
     */
    readonly awsAccountId: pulumi.Output<string | undefined>;
    /**
     * <p>The time that the VPC connection was created.</p>
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * A list of IP addresses of DNS resolver endpoints for the VPC connection.
     */
    readonly dnsResolvers: pulumi.Output<string[] | undefined>;
    /**
     * <p>The time that the VPC connection was last updated.</p>
     */
    readonly lastUpdatedTime: pulumi.Output<string>;
    /**
     * The display name for the VPC connection.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * <p>A list of network interfaces.</p>
     */
    readonly networkInterfaces: pulumi.Output<outputs.quicksight.VpcConnectionNetworkInterface[]>;
    /**
     * The ARN of the IAM role associated with the VPC connection.
     */
    readonly roleArn: pulumi.Output<string | undefined>;
    /**
     * The Amazon EC2 security group IDs associated with the VPC connection.
     */
    readonly securityGroupIds: pulumi.Output<string[] | undefined>;
    /**
     * The HTTP status of the request.
     */
    readonly status: pulumi.Output<enums.quicksight.VpcConnectionVpcConnectionResourceStatus>;
    /**
     * A list of subnet IDs for the VPC connection.
     */
    readonly subnetIds: pulumi.Output<string[] | undefined>;
    /**
     * A map of the key-value pairs for the resource tag or tags assigned to the VPC connection.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ID of the VPC connection that you're creating. This ID is a unique identifier for each AWS Region in an AWS account.
     */
    readonly vpcConnectionId: pulumi.Output<string | undefined>;
    /**
     * <p>The Amazon EC2 VPC ID associated with the VPC connection.</p>
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a VpcConnection resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: VpcConnectionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VpcConnection resource.
 */
export interface VpcConnectionArgs {
    /**
     * The availability status of the VPC connection.
     */
    availabilityStatus?: pulumi.Input<enums.quicksight.VpcConnectionVpcConnectionAvailabilityStatus>;
    /**
     * The AWS account ID of the account where you want to create a new VPC connection.
     */
    awsAccountId?: pulumi.Input<string>;
    /**
     * A list of IP addresses of DNS resolver endpoints for the VPC connection.
     */
    dnsResolvers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The display name for the VPC connection.
     */
    name?: pulumi.Input<string>;
    /**
     * The ARN of the IAM role associated with the VPC connection.
     */
    roleArn?: pulumi.Input<string>;
    /**
     * The Amazon EC2 security group IDs associated with the VPC connection.
     */
    securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A list of subnet IDs for the VPC connection.
     */
    subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A map of the key-value pairs for the resource tag or tags assigned to the VPC connection.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The ID of the VPC connection that you're creating. This ID is a unique identifier for each AWS Region in an AWS account.
     */
    vpcConnectionId?: pulumi.Input<string>;
}
