import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Enables access logs to be sent to Amazon CloudWatch, Amazon S3, and Amazon Kinesis Data Firehose. The service network owner can use the access logs to audit the services in the network. The service network owner will only see access logs from clients and services that are associated with their service network. Access log entries represent traffic originated from VPCs associated with that network.
 */
export declare class AccessLogSubscription extends pulumi.CustomResource {
    /**
     * Get an existing AccessLogSubscription resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AccessLogSubscription;
    /**
     * Returns true if the given object is an instance of AccessLogSubscription.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AccessLogSubscription;
    /**
     * The Amazon Resource Name (ARN) of the access log subscription.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the access log subscription.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the destination. The supported destination types are CloudWatch Log groups, Kinesis Data Firehose delivery streams, and Amazon S3 buckets.
     */
    readonly destinationArn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the access log subscription.
     */
    readonly resourceArn: pulumi.Output<string>;
    /**
     * The ID of the service network or service.
     */
    readonly resourceId: pulumi.Output<string>;
    /**
     * The ID or ARN of the service network or service.
     */
    readonly resourceIdentifier: pulumi.Output<string | undefined>;
    /**
     * Log type of the service network.
     */
    readonly serviceNetworkLogType: pulumi.Output<enums.vpclattice.AccessLogSubscriptionServiceNetworkLogType | undefined>;
    /**
     * The tags for the access log subscription.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a AccessLogSubscription resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AccessLogSubscriptionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AccessLogSubscription resource.
 */
export interface AccessLogSubscriptionArgs {
    /**
     * The Amazon Resource Name (ARN) of the destination. The supported destination types are CloudWatch Log groups, Kinesis Data Firehose delivery streams, and Amazon S3 buckets.
     */
    destinationArn: pulumi.Input<string>;
    /**
     * The ID or ARN of the service network or service.
     */
    resourceIdentifier?: pulumi.Input<string>;
    /**
     * Log type of the service network.
     */
    serviceNetworkLogType?: pulumi.Input<enums.vpclattice.AccessLogSubscriptionServiceNetworkLogType>;
    /**
     * The tags for the access log subscription.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
