import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A target group is a collection of targets, or compute resources, that run your application or service. A target group can only be used by a single service.
 */
export declare function getTargetGroup(args: GetTargetGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetTargetGroupResult>;
export interface GetTargetGroupArgs {
    /**
     * The Amazon Resource Name (ARN) of the target group.
     */
    arn: string;
}
export interface GetTargetGroupResult {
    /**
     * The Amazon Resource Name (ARN) of the target group.
     */
    readonly arn?: string;
    /**
     * The target group configuration.
     */
    readonly config?: outputs.vpclattice.TargetGroupConfig;
    /**
     * The date and time that the target group was created, specified in ISO-8601 format.
     */
    readonly createdAt?: string;
    /**
     * The ID of the target group.
     */
    readonly id?: string;
    /**
     * The date and time that the target group was last updated, specified in ISO-8601 format.
     */
    readonly lastUpdatedAt?: string;
    /**
     * The operation's status. You can retry the operation if the status is `CREATE_FAILED` . However, if you retry it while the status is `CREATE_IN_PROGRESS` , there is no change in the status.
     */
    readonly status?: enums.vpclattice.TargetGroupStatus;
    /**
     * The tags for the target group.
     */
    readonly tags?: outputs.Tag[];
    /**
     * Describes a target.
     */
    readonly targets?: outputs.vpclattice.TargetGroupTarget[];
}
/**
 * A target group is a collection of targets, or compute resources, that run your application or service. A target group can only be used by a single service.
 */
export declare function getTargetGroupOutput(args: GetTargetGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTargetGroupResult>;
export interface GetTargetGroupOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the target group.
     */
    arn: pulumi.Input<string>;
}
