import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Wisdom::AIAgent Resource Type
 */
export declare class AiAgent extends pulumi.CustomResource {
    /**
     * Get an existing AiAgent resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AiAgent;
    /**
     * Returns true if the given object is an instance of AiAgent.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AiAgent;
    /**
     * The Amazon Resource Name (ARN) of the AI agent.
     */
    readonly aiAgentArn: pulumi.Output<string>;
    /**
     * The identifier of the AI Agent.
     */
    readonly aiAgentId: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the Amazon Q in Connect assistant.
     */
    readonly assistantArn: pulumi.Output<string>;
    /**
     * The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
     */
    readonly assistantId: pulumi.Output<string>;
    /**
     * Configuration for the AI Agent.
     */
    readonly configuration: pulumi.Output<outputs.wisdom.AiAgentAiAgentConfiguration0Properties | outputs.wisdom.AiAgentAiAgentConfiguration1Properties | outputs.wisdom.AiAgentAiAgentConfiguration2Properties>;
    /**
     * The description of the AI Agent.
     */
    readonly description: pulumi.Output<string | undefined>;
    readonly modifiedTimeSeconds: pulumi.Output<number>;
    /**
     * The name of the AI Agent.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The type of the AI Agent.
     */
    readonly type: pulumi.Output<enums.wisdom.AiAgentAiAgentType>;
    /**
     * Create a AiAgent resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AiAgentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AiAgent resource.
 */
export interface AiAgentArgs {
    /**
     * The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
     */
    assistantId: pulumi.Input<string>;
    /**
     * Configuration for the AI Agent.
     */
    configuration: pulumi.Input<inputs.wisdom.AiAgentAiAgentConfiguration0PropertiesArgs | inputs.wisdom.AiAgentAiAgentConfiguration1PropertiesArgs | inputs.wisdom.AiAgentAiAgentConfiguration2PropertiesArgs>;
    /**
     * The description of the AI Agent.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the AI Agent.
     */
    name?: pulumi.Input<string>;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The type of the AI Agent.
     */
    type: pulumi.Input<enums.wisdom.AiAgentAiAgentType>;
}
